Installation
============

To install the latest version of `django_dicom`, simply run::

    pip install django_dicom

or, using `poetry <https://github.com/sdispater/poetry>`_::

    poetry add django_dicom

